Class: Google::Apis::TexttospeechV1beta1::SynthesisInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/texttospeech_v1beta1/classes.rb,
lib/google/apis/texttospeech_v1beta1/representations.rb,
lib/google/apis/texttospeech_v1beta1/representations.rb

Overview

Contains text input to be synthesized. Either text or ssml must be supplied. Supplying both or neither returns google.rpc.Code.INVALID_ARGUMENT. The input size is limited to 5000 bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SynthesisInput

Returns a new instance of SynthesisInput.



556
557
558
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_pronunciationsGoogle::Apis::TexttospeechV1beta1::CustomPronunciations

A collection of pronunciation customizations. Corresponds to the JSON property customPronunciations



522
523
524
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 522

def custom_pronunciations
  @custom_pronunciations
end

#markupString

Markup for Chirp 3: HD voices specifically. This field may not be used with any other voices. Corresponds to the JSON property markup

Returns:

  • (String)


528
529
530
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 528

def markup
  @markup
end

#multi_speaker_markupGoogle::Apis::TexttospeechV1beta1::MultiSpeakerMarkup

A collection of turns for multi-speaker synthesis. Corresponds to the JSON property multiSpeakerMarkup



533
534
535
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 533

def multi_speaker_markup
  @multi_speaker_markup
end

#promptString

This system instruction is supported only for controllable/promptable voice models. If this system instruction is used, we pass the unedited text to Gemini-TTS. Otherwise, a default system instruction is used. AI Studio calls this system instruction, Style Instructions. Corresponds to the JSON property prompt

Returns:

  • (String)


541
542
543
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 541

def prompt
  @prompt
end

#ssmlString

The SSML document to be synthesized. The SSML document must be valid and well- formed. Otherwise the RPC will fail and return google.rpc.Code. INVALID_ARGUMENT. For more information, see SSML. Corresponds to the JSON property ssml

Returns:

  • (String)


549
550
551
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 549

def ssml
  @ssml
end

#textString

The raw text to be synthesized. Corresponds to the JSON property text

Returns:

  • (String)


554
555
556
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 554

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



561
562
563
564
565
566
567
568
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 561

def update!(**args)
  @custom_pronunciations = args[:custom_pronunciations] if args.key?(:custom_pronunciations)
  @markup = args[:markup] if args.key?(:markup)
  @multi_speaker_markup = args[:multi_speaker_markup] if args.key?(:multi_speaker_markup)
  @prompt = args[:prompt] if args.key?(:prompt)
  @ssml = args[:ssml] if args.key?(:ssml)
  @text = args[:text] if args.key?(:text)
end