Class: Google::Apis::TexttospeechV1beta1::VoiceSelectionParams
- Inherits:
-
Object
- Object
- Google::Apis::TexttospeechV1beta1::VoiceSelectionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/texttospeech_v1beta1/classes.rb,
lib/google/apis/texttospeech_v1beta1/representations.rb,
lib/google/apis/texttospeech_v1beta1/representations.rb
Overview
Description of which voice to use for a synthesis request.
Instance Attribute Summary collapse
-
#custom_voice ⇒ Google::Apis::TexttospeechV1beta1::CustomVoiceParams
Description of the custom voice to be synthesized.
-
#language_code ⇒ String
Required.
-
#model_name ⇒ String
Optional.
-
#multi_speaker_voice_config ⇒ Google::Apis::TexttospeechV1beta1::MultiSpeakerVoiceConfig
Configuration for a multi-speaker text-to-speech setup.
-
#name ⇒ String
The name of the voice.
-
#ssml_gender ⇒ String
The preferred gender of the voice.
-
#voice_clone ⇒ Google::Apis::TexttospeechV1beta1::VoiceCloneParams
The configuration of Voice Clone feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VoiceSelectionParams
constructor
A new instance of VoiceSelectionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VoiceSelectionParams
Returns a new instance of VoiceSelectionParams.
890 891 892 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_voice ⇒ Google::Apis::TexttospeechV1beta1::CustomVoiceParams
Description of the custom voice to be synthesized.
Corresponds to the JSON property customVoice
841 842 843 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 841 def custom_voice @custom_voice end |
#language_code ⇒ String
Required. The language (and potentially also the region) of the voice
expressed as a BCP-47 language
tag, e.g. "en-US". This should not include a script tag (e.g. use "cmn-cn"
rather than "cmn-Hant-cn"), because the script will be inferred from the input
provided in the SynthesisInput. The TTS service will use this parameter to
help choose an appropriate voice. Note that the TTS service may choose a voice
with a slightly different language code than the one selected; it may
substitute a different region (e.g. using en-US rather than en-CA if there isn'
t a Canadian voice available), or even a different language, e.g. using "nb" (
Norwegian Bokmal) instead of "no" (Norwegian)".
Corresponds to the JSON property languageCode
855 856 857 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 855 def language_code @language_code end |
#model_name ⇒ String
Optional. The name of the model. If set, the service will choose the model
matching the specified configuration.
Corresponds to the JSON property modelName
861 862 863 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 861 def model_name @model_name end |
#multi_speaker_voice_config ⇒ Google::Apis::TexttospeechV1beta1::MultiSpeakerVoiceConfig
Configuration for a multi-speaker text-to-speech setup. Enables the use of up
to two distinct voices in a single synthesis request.
Corresponds to the JSON property multiSpeakerVoiceConfig
867 868 869 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 867 def multi_speaker_voice_config @multi_speaker_voice_config end |
#name ⇒ String
The name of the voice. If both the name and the gender are not set, the
service will choose a voice based on the other parameters such as
language_code.
Corresponds to the JSON property name
874 875 876 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 874 def name @name end |
#ssml_gender ⇒ String
The preferred gender of the voice. If not set, the service will choose a voice
based on the other parameters such as language_code and name. Note that this
is only a preference, not requirement; if a voice of the appropriate gender is
not available, the synthesizer should substitute a voice with a different
gender rather than failing the request.
Corresponds to the JSON property ssmlGender
883 884 885 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 883 def ssml_gender @ssml_gender end |
#voice_clone ⇒ Google::Apis::TexttospeechV1beta1::VoiceCloneParams
The configuration of Voice Clone feature.
Corresponds to the JSON property voiceClone
888 889 890 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 888 def voice_clone @voice_clone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
895 896 897 898 899 900 901 902 903 |
# File 'lib/google/apis/texttospeech_v1beta1/classes.rb', line 895 def update!(**args) @custom_voice = args[:custom_voice] if args.key?(:custom_voice) @language_code = args[:language_code] if args.key?(:language_code) @model_name = args[:model_name] if args.key?(:model_name) @multi_speaker_voice_config = args[:multi_speaker_voice_config] if args.key?(:multi_speaker_voice_config) @name = args[:name] if args.key?(:name) @ssml_gender = args[:ssml_gender] if args.key?(:ssml_gender) @voice_clone = args[:voice_clone] if args.key?(:voice_clone) end |