Class: Google::Apis::TexttospeechV1beta1::TexttospeechService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::TexttospeechV1beta1::TexttospeechService
- Defined in:
- lib/google/apis/texttospeech_v1beta1/service.rb
Overview
Cloud Text-to-Speech API
Synthesizes natural-sounding speech by applying powerful neural network models.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://texttospeech.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ TexttospeechService
constructor
A new instance of TexttospeechService.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_voices(language_code: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::ListVoicesResponse
Returns a list of Voice supported for synthesis.
-
#synthesize_location_long_audio(parent, synthesize_long_audio_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::Operation
Synthesizes long form text asynchronously.
-
#synthesize_text_speech(synthesize_speech_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::SynthesizeSpeechResponse
Synthesizes speech synchronously: receive results after all text input has been processed.
Constructor Details
#initialize ⇒ TexttospeechService
Returns a new instance of TexttospeechService.
47 48 49 50 51 52 |
# File 'lib/google/apis/texttospeech_v1beta1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-texttospeech_v1beta1', client_version: Google::Apis::TexttospeechV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/texttospeech_v1beta1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/texttospeech_v1beta1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
108 109 110 111 112 113 114 115 116 |
# File 'lib/google/apis/texttospeech_v1beta1/service.rb', line 108 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::TexttospeechV1beta1::Operation::Representation command.response_class = Google::Apis::TexttospeechV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/google/apis/texttospeech_v1beta1/service.rb', line 153 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::TexttospeechV1beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::TexttospeechV1beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_voices(language_code: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::ListVoicesResponse
Returns a list of Voice supported for synthesis.
223 224 225 226 227 228 229 230 231 |
# File 'lib/google/apis/texttospeech_v1beta1/service.rb', line 223 def list_voices(language_code: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/voices', ) command.response_representation = Google::Apis::TexttospeechV1beta1::ListVoicesResponse::Representation command.response_class = Google::Apis::TexttospeechV1beta1::ListVoicesResponse command.query['languageCode'] = language_code unless language_code.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#synthesize_location_long_audio(parent, synthesize_long_audio_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::Operation
Synthesizes long form text asynchronously.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/texttospeech_v1beta1/service.rb', line 75 def synthesize_location_long_audio(parent, synthesize_long_audio_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}:synthesizeLongAudio', ) command.request_representation = Google::Apis::TexttospeechV1beta1::SynthesizeLongAudioRequest::Representation command.request_object = synthesize_long_audio_request_object command.response_representation = Google::Apis::TexttospeechV1beta1::Operation::Representation command.response_class = Google::Apis::TexttospeechV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#synthesize_text_speech(synthesize_speech_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TexttospeechV1beta1::SynthesizeSpeechResponse
Synthesizes speech synchronously: receive results after all text input has been processed.
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/google/apis/texttospeech_v1beta1/service.rb', line 187 def synthesize_text_speech(synthesize_speech_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/text:synthesize', ) command.request_representation = Google::Apis::TexttospeechV1beta1::SynthesizeSpeechRequest::Representation command.request_object = synthesize_speech_request_object command.response_representation = Google::Apis::TexttospeechV1beta1::SynthesizeSpeechResponse::Representation command.response_class = Google::Apis::TexttospeechV1beta1::SynthesizeSpeechResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |